==> keyclic_sdk_api-1.28.3.tar.gz: lib/model/category.dart <==
part of keyclic_sdk_api.api;

class Category {
  
  String color = null;
  

  String icon = null;
  

  String name = null;
  

  String id = null;
  

  String identificationNumber = null;
  

  DateTime createdAt = null;
  

  String type = null;
  

  CategoryLinks links = null;
  
  Category();

  @override
  String toString() {
    return 'Category[color=$color, icon=$icon, name=$name, id=$id, identificationNumber=$identificationNumber, createdAt=$createdAt, type=$type, links=$links, ]';
  }

  Category.fromJson(Map<String, dynamic> json) {
    if (json == null) return;
    color =
        json['color']
    ;
    icon =
        json['icon']
    ;
    name =
        json['name']
    ;
    id =
        json['id']
    ;
    identificationNumber =
        json['identificationNumber']
    ;
    createdAt = json['createdAt'] == null ? null : DateTime.parse(json['createdAt']);
    type =
        json['type']
    ;
    links =
      
      
      new CategoryLinks.fromJson(json['links'])
;
  }

  Map<String, dynamic> toJson() {
    return {
      'color': color,
      'icon': icon,
      'name': name,
      'id': id,
      'identificationNumber': identificationNumber,
      'createdAt': createdAt == null ? '' : createdAt.toUtc().toIso8601String(),
      'type': type,
      'links': links
     };
  }

  static List<Category> listFromJson(List<dynamic> json) {
    return json == null ? new List<Category>() : json.map((value) => new Category.fromJson(value)).toList();
  }

  static Map<String, Category> mapFromJson(Map<String, Map<String, dynamic>> json) {
    var map = new Map<String, Category>();
    if (json != null && json.length > 0) {
      json.forEach((String key, Map<String, dynamic> value) => map[key] = new Category.fromJson(value));
    }
    return map;
  }
}

==> keyclic_sdk_api-1.28.6.tar.gz: lib/model/category.dart <==
part of keyclic_sdk_api.api;

class Category {
  String color = null;

  String icon = null;

  String name = null;

  String id = null;

  String identificationNumber = null;

  DateTime createdAt = null;

  String type = null;

  CategoryLinks links = null;

  Category();

  @override
  String toString() {
    return 'Category[color=$color, icon=$icon, name=$name, id=$id, identificationNumber=$identificationNumber, createdAt=$createdAt, type=$type, links=$links, ]';
  }

  Category.fromJson(Map<String, dynamic> json) {
    if (json == null) return;
    color = json['color'];
    icon = json['icon'];
    name = json['name'];
    id = json['id'];
    identificationNumber = json['identificationNumber'];
    createdAt =
        json['createdAt'] == null ? null : DateTime.parse(json['createdAt']);
    type = json['type'];
    links = new CategoryLinks.fromJson(json['links']);
  }

  Map<String, dynamic> toJson() {
    return {
      'color': color,
      'icon': icon,
      'name': name,
      'id': id,
      'identificationNumber': identificationNumber,
      'createdAt': createdAt == null ? '' : createdAt.toUtc().toIso8601String(),
      'type': type,
      'links': links
    };
  }

  static List<Category> listFromJson(List<dynamic> json) {
    return json == null
        ? new List<Category>()
        : json.map((value) => new Category.fromJson(value)).toList();
  }

  static Map<String, Category> mapFromJson(
      Map<String, Map<String, dynamic>> json) {
    var map = new Map<String, Category>();
    if (json != null && json.length > 0) {
      json.forEach((String key, Map<String, dynamic> value) =>
          map[key] = new Category.fromJson(value));
    }
    return map;
  }
}
